@@ -4,20 +4,19 @@
 #'
 #' @param scrape HTML Output from Scraping Google Form
 #' @export
-#' @importFrom magrittr %>%
-#' @examples \dontrun{
+#' @examples
+#' \dontrun{
 #' url %>% get_form() %>% get_form_questions() -> questions
 #' }
 get_form_questions <- function (scrape) {
-    . <- NULL
-    qt <- rvest::html_nodes(scrape, ".ss-q-title") %>% rvest::html_text() %>%
-        gsub("\n", "", .)
+    qt <- gsub("\n", ""
+               , rvest::html_text(
+                 rvest::html_nodes(scrape
+                                   , ".ss-q-title") ) )
     if (length(qt) != 0) {
         qt
-    }
-    else {
-        rvest::html_nodes(scrape, ".freebirdFormviewerViewItemsItemItemTitle") %>%
-            rvest::html_text()
+    } else {
+      rvest::html_text(rvest::html_nodes(scrape, ".freebirdFormviewerViewItemsItemItemTitle"))
     }
 }
 
